// *******************************************************************************
// *
// * Copyright  GoFlight Inc.  All rights reserved.
// *
// * Module Name:
// *   GFDevApi.h
// *
// * Doyle Nickless -- 14 May 2004 (GF SDK 1.51)
// *
// * Abstract:
// *   Header for GoFlight device control library.  Support is included for the
// *   following GoFlight hardware:
// * 
// *      GF-45 Avionics Simulation Unit
// *      GF-45PM Display Panel Module
// *      GF-46 Multi-Mode Display Module
// *      GF-P8 Pushbutton/LED Module
// *      GF-T8 Toggle Switch/LED Module
// *      GF-LGT Landing Gear/Trim control module
// *      GF-166 Versatile Radio Panel
// *      GF-MCP Advanced Autopilot Module
// *      GF-RP48 Rotary/Pushbutton/LED Module
// *      GF-TQ6 Throttle System
// *      GF-ATC Headset Comms Panel
// *
// * Environment:
// *   Microsoft Windows -- User mode
// *
// *******************************************************************************

#ifndef _GFDEVAPI_H_DEFINED_
#define _GFDEVAPI_H_DEFINED_

// === Data types =============================================================
//
// For use in Mac environments, we define the standard 'loud' datatypes. 
#ifndef _WINDOWS
	typedef	unsigned char	BYTE;
	typedef	void *			HINSTANCE;
	typedef	char			BOOL;
	typedef	long			DWORD;
	#define	MAX_PATH		512
#define	_cdecl
#endif

#pragma pack( push, gfdevapi_h ) // Save current pack value

#pragma pack(1)
//
// Tokens for GoFlight device types
//
typedef enum tagGFDevHWType
{
	GFDEVHWTYPE_NONE    = 0, // Sentinel value (No Hardware.)
	GFDEVHWTYPE_GF45    = 1, // GF-45 Avionics Simulation Unit
	GFDEVHWTYPE_GFP8,        // GF-P8 8 pushbutton/LED control module
	GFDEVHWTYPE_GFT8,		 // GF-T8 8 toggle switch/LED control module
	GFDEVHWTYPE_GFLGT,       // GF-LGT Landing Gear/Trim control module
	GFDEVHWTYPE_GF166,       // GF-166 Versatile Radio Panel
	GFDEVHWTYPE_GFMCP,       // GF-MCP Advanced autopilot module
	GFDEVHWTYPE_GFRP48,      // GF-RP48 rotary/pushbutton/LED control module
    GFDEVHWTYPE_GF46,        // GF-46 Multifunction Module
    GFDEVHWTYPE_GFTQ6,       // GF-TQ6 Throttle System
    GFDEVHWTYPE_GFATC        // GF-ATC Headset Comms Panel
} GFDEV_HW_TYPE;

//
// Device connect/disconnect tokens for use with the Connect callbacks
//
typedef enum tagEventToken
{
	EVENT_DEVICE_CONNECT     = 1,
	EVENT_DEVICE_DISCONNECT

} GFDEV_EVENT_TOKEN;

//
// GFDEVRESULT values are retured from the GFDEV API functions.
//
typedef enum tagGFDevResult
{
	GFDEV_OK = 0,
    GFDEV_ERR_INVALID_DEVICE_INDEX,
	GFDEV_ERR_INSUFFICIENT_MEMORY,
	GFDEV_ERR_DEVICE_NOT_PRESENT,
	GFDEV_ERR_COMMAND_QUEUE,
	GFDEV_ERR_HID_GET_FEATURE,
	GFDEV_ERR_HID_SET_FEATURE,
	GFDEV_ERR_SET_DATA_NOT_VERIFIED,
	GFDEV_ERR_NO_DATA_AVAIL,
	GFDEV_ERR_UNSUPPORTED_OS,
	GFDEV_ERR_DLL_NOT_FOUND,
	GFDEV_ERR_INVALID_ARG,
	GFDEV_ERR_API_NOT_INIT

} GFDEVRESULT;

//
// GFDEVICEINFO struct contains internal information about GoFlight devices
//
typedef struct tagGFDeviceInfo
	{
	char szLocationID[MAX_PATH];
	unsigned short wDeviceVersion;
	} GFDEVICEINFO, *LPGFDEVICEINFO;

//
// GF-45 input report
//
typedef struct tagGF45InputReport
	{
	short nLDialVal;
	short nRDialVal;
	} GF45INPUTREPORT, *LPGF45INPUTREPORT;
//
// GF-46 input report
//
typedef struct tagGF46InputReport
	{
	short nLgDialVal;
	short nSmDialVal;
	BYTE  bSwitchState; // Function pushbutton state
	} GF46INPUTREPORT, *LPGF46INPUTREPORT;
//
// GF-RP48 input report
//
typedef struct tagGFRP48InputReport
	{
	short nADialVal;            // encoder "A"
	short nBDialVal;            // encoder "B"
	short nCDialVal;            // encoder "C"
	short nDDialVal;            // encoder "D"
	unsigned char bSwitchState; // Buttons 1-8
	} GFRP48INPUTREPORT, *LPGFRP48INPUTREPORT;
//
// GF-LGT input report (returned from InputCallback())
//
typedef struct tagGFLGTInputReport
	{
	signed short nWheelVal;
	unsigned char bSwitchState;
	} GFLGTINPUTREPORT, *LPGFLGTINPUTREPORT;
//
// GF-166 input report
//
typedef struct tagGF166InputReport
	{
	short nLgDialVal;           // Coarse encoder
	short nSmDialVal;           // Fine encoder
	unsigned char bSwitchState; // Function pushbuttons
	} GF166INPUTREPORT, *LPGF166INPUTREPORT;
//
// GF-MCP input report
//
typedef struct tagGFMCPInputReport
	{
	short nADialVal;                // encoder "A" (leftmost knob)
	short nBDialVal;                // encoder "B"
	short nCDialVal;                // encoder "C"
	short nDDialVal;                // encoder "D"
	short nEDialVal;                // encoder "E" (rightmost knob)
	unsigned char bSwitchState1_8;  // Switches 1-8
    unsigned char bSwitchState9_16; // Switches 9-16
	} GFMCPINPUTREPORT, *LPGFMCPINPUTREPORT;
//
// GF-TQ6 input report
//
typedef struct tagGFTQ6InputReport
	{
	unsigned char bLeverAVal;       // Control Lever A (leftmost slot)
	unsigned char bLeverBVal;       // Control Lever B
	unsigned char bLeverCVal;       // Control Lever C
	unsigned char bLeverDVal;       // Control Lever D
	unsigned char bLeverEVal;       // Control Lever E
	unsigned char bLeverFVal;       // Control Lever F (rightmost slot)
	unsigned char bSwitchState;     // Control lever switches
	} GFTQ6INPUTREPORT, *LPGFTQ6INPUTREPORT;
//
// GF-ATC input report
//
typedef struct tagGFATCInputReport
	{
	short nDialVal;                 // Selection knob
    unsigned char bSwitchState;     // Selection knob push switch
	} GFATCINPUTREPORT, *LPGFATCINPUTREPORT;

//
// Bitmasks for access to GF-LGT switch and LED states
//
// GF-LGT switch states
#define GFLGT_SW_LEVER_UP     0x01 // b0 : '1' = lever up
#define GFLGT_SW_SWITCH_DN    0x02 // b1 : '1' = mom. switch down
#define GFLGT_SW_SWITCH_UP    0x04 // b2 : '1' = mom. switch up
//
// GF-LGT gear status LED states
                                    // b0 : ignored 	
                                    // b1 : ignored 	
#define GFLGT_LED_RIGHT_RED    0x04 // b2 : '1' Right gear red
#define GFLGT_LED_RIGHT_GREEN  0x08 // b3 : '1' Right gear green
#define GFLGT_LED_RIGHT_AMBER  (GFLGT_LED_RIGHT_RED | GFLGT_LED_RIGHT_GREEN)

#define GFLGT_LED_LEFT_RED     0x10 // b4 : '1' Left gear red
#define GFLGT_LED_LEFT_GREEN   0x20 // b5 : '1' Left gear green
#define GFLGT_LED_LEFT_AMBER   (GFLGT_LED_LEFT_RED | GFLGT_LED_LEFT_GREEN)

#define GFLGT_LED_NOSE_RED     0x40 // b6 : '1' Nose gear red
#define GFLGT_LED_NOSE_GREEN   0x80 // b7 : '1' Nose gear green
#define GFLGT_LED_NOSE_AMBER   (GFLGT_LED_NOSE_RED | GFLGT_LED_NOSE_GREEN)

#define GFLGT_LED_ALL_OFF      0x00 // All three gear status LEDs off
#define GFLGT_LED_ALL_RED      0x54 // All three gear status LEDs red
#define GFLGT_LED_ALL_GREEN    0xA8 // All three gear status LEDs off
#define GFLGT_LED_ALL_AMBER    (GFLGT_LED_RIGHT_AMBER | GFLGT_LED_LEFT_AMBER | GFLGT_LED_NOSE_AMBER)

//
// Bitmask for access to GF-46 function button
//
// GF-46 function button -- '1' = button pressed, '0' = button released.
#define GF46_BTN_FUNC         0x01 // Function button (LSB)
                                   // All other bits will read a constant '0'

//
// Bitmasks for access to GF-166 function buttons and LED states
//
// GF-166 function buttons -- '1' = button pressed, '0' = button released.
#define GF166_BTN_FUNC_C       0x01 // Center function button
#define GF166_BTN_FUNC_L       0x02 // Left function button
#define GF166_BTN_FUNC_R       0x04 // Right function button

// GF-166 LED indicators -- '1' LED is on, '0' = LED is off
#define GF166_LED_FUNC_C       0x01 // Center function indicator (NOTE: on the -166A,
                                    //   there is no physical LED here.  But this bit
                                    //   position is reserved in case one is added
								    //   on future revs.
#define GF166_LED_FUNC_L       0x02 // Left function indicator
#define GF166_LED_FUNC_R       0x04 // Center function indicator (NOTE: on the -166A,

//
// Bitmasks for access to GF-MCP switch and LED states
//
#define GFMCP_SW_1             0x01 // Switch 1 rectangular pushbutton, leftmost on panel
#define GFMCP_LED_1            0x01 // LED 1 integrated with Switch 1
#define GFMCP_SW_2             0x02 // Switch 2 rectangular pushbutton, right of Switch 1
#define GFMCP_LED_2            0x02 // LED 2 integrated with Switch 2
#define GFMCP_SW_3             0x04 // Switch 3 rectangular pushbutton, right of Switch 2
#define GFMCP_LED_3            0x04 // LED 3 integrated with Switch 3
#define GFMCP_SW_4             0x08 // Switch 4 round pushbutton, below digit 1 of display "C"
#define GFMCP_LED_4            0x08 // LED 4 not present on current rev of MCP (future)
#define GFMCP_SW_5             0x10 // Switch 5 rectangular pushbutton, right of Dial D (wheel control)
#define GFMCP_LED_5            0x10 // LED 5 integrated with Switch 5
#define GFMCP_SW_6             0x20 // Switch 6 rectangular pushbutton, right of Switch 5
#define GFMCP_LED_6            0x20 // LED 6 integrated with Switch 6
#define GFMCP_SW_7             0x40 // Switch 7 rectangular pushbutton, right of Switch 6
#define GFMCP_LED_7            0x40 // LED 7 integrated with Switch 7
#define GFMCP_SW_8             0x80 // Switch 8 rectangular pushbutton, lower left panel
#define GFMCP_LED_8            0x80 // LED 8 integrated with Switch 8

#define GFMCP_SW_9             0x01 // Switch 9 toggle switch connected to "disengage" bar
#define GFMCP_SW_10            0x02 // Switch 10 is HDG knob "push" switch; added in GF-MCP
                                    // SMT1 board rev. 
//
// Bitmasks for access to GF-TQ6 control lever switch states
//
#define GFTQ6_SW_A             0x01 // Control Lever Switch "A" (currently not installed)
#define GFTQ6_SW_B             0x02 // Control Lever Switch "B"
#define GFTQ6_SW_C             0x04 // Control Lever Switch "C"
#define GFTQ6_SW_D             0x08 // Control Lever Switch "D"
#define GFTQ6_SW_E             0x10 // Control Lever Switch "E"
#define GFTQ6_SW_F             0x20 // Control Lever Switch "F" (currently not installed)

//
// Bitmasks for access to GF-ATC switch states
//
#define GFATC_KNOB_PUSH        0x01 // Selection knob push switch


// === Function Prototypes ====================================================
//
// Define API functions extern "C" when included in C++ source; by default, _cdecl
//   calling convention will be used 
//
#if defined( __cplusplus)
extern "C" 
{
#endif
	// The main initialization function for the GFDEV API.
	GFDEVRESULT GFDev_Init( HINSTANCE hAppInstance );
	// Function for getting internal information about a specific GoFlight device.
	GFDEVRESULT GFDev_GetDeviceInfo( GFDEV_HW_TYPE HWType, int nDevIndex, LPGFDEVICEINFO pGFDI );
	// The main teardown function for the GFDEV API.
	GFDEVRESULT GFDev_Terminate( void );

	// Input callback is called any time new input data arrives from connected hardware.
	//   A single callback processes data for all instances and types of GoFlight hardware.
	BOOL GFDev_RegisterInputCallback( BOOL (_cdecl *pfnInputCallback)(GFDEV_HW_TYPE, unsigned short, unsigned long) );
	BOOL GFDev_UnregisterInputCallback( void );

	// Connect callback is called from the API as the result of a hardware connect or disconnect event.
	//   The API is thus able to notify the client app of device connection and disconnection.
    BOOL GFDev_RegisterConnectCallback( BOOL (_cdecl *pfnConnectCallback)(GFDEV_HW_TYPE, unsigned short, GFDEV_EVENT_TOKEN) );
	BOOL GFDev_UnregisterConnectCallback( void );
    
	// Wakeup callback is called at regular intervals -- useful for general-purpose timing.
	//   Time interval is based on thread sleep time.
    BOOL GFDev_RegisterWakeupCallback( BOOL (_cdecl *pfnWakeupCallback)( void ), DWORD dwCallbackInterval );
	BOOL GFDev_UnregisterWakeupCallback( void );
    
	// GF-45 specific API functions
	unsigned short GF45_GetNumDevices ( void );
    GFDEVRESULT GF45_GetDialVals( int nDevIndex, short *pnLDialVal, short *pnRDialVal );
	GFDEVRESULT GF45_SetBrightness( int nDevIndex, int nBrightLevel );	
    GFDEVRESULT GF45_SetAlpha( int nDevIndex, char* szValue );
	GFDEVRESULT GF45_SetAlphaSegments( int nDevIndex, unsigned char* pszSegData );
	GFDEVRESULT GF45_SetNumeric( int nDevIndex, char* szValue );
	GFDEVRESULT GF45_SetNumericSegments( int nDevIndex, unsigned char* pszSegData );
    
	// GF-46 specific API functions
	unsigned short GF46_GetNumDevices ( void );
    GFDEVRESULT GF46_GetControlVals( int nDevIndex, short *pnLgDialVal, short *pnSmDialVal, unsigned char* pbSwitchVal );
    GFDEVRESULT GF46_SetAlpha( int nDevIndex, char* szValue );
	GFDEVRESULT GF46_SetAlphaSegments( int nDevIndex, unsigned char* pszSegData );
	GFDEVRESULT GF46_SetNumeric( int nDevIndex, char* szValue );
	GFDEVRESULT GF46_SetNumericSegments( int nDevIndex, unsigned char* pszSegData );
	GFDEVRESULT GF46_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GF46_SetBrightness( int nDevIndex, int nBrightLevel );	
    
	// GF-P8 specific API functions
	unsigned short GFP8_GetNumDevices ( void );
	GFDEVRESULT GFP8_GetSwitchVals( int nDevIndex, unsigned char* pbSwitchVals );
	GFDEVRESULT GFP8_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
	GFDEVRESULT GFP8_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
	GFDEVRESULT GFP8_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GFP8_SetBrightness( int nDevIndex, int nBrightLevel );

	// GF-RP48 specific API functions
	unsigned short GFRP48_GetNumDevices ( void );
	GFDEVRESULT GFRP48_GetControlVals( int nDevIndex, short* pnADialVal, short* pnBDialVal, short* pnCDialVal, short* pnDDialVal, unsigned char* pbSwitchVals );
	GFDEVRESULT GFRP48_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
	GFDEVRESULT GFRP48_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
	GFDEVRESULT GFRP48_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GFRP48_SetBrightness( int nDevIndex, int nBrightLevel );
    
	// GF-T8 specific API functions
	unsigned short GFT8_GetNumDevices ( void );
	GFDEVRESULT GFT8_GetSwitchVals( int nDevIndex, unsigned char* pbSwitchVals );
	GFDEVRESULT GFT8_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
	GFDEVRESULT GFT8_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
	GFDEVRESULT GFT8_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GFT8_SetBrightness( int nDevIndex, int nBrightLevel );
    
	// GF-LGT specific API functions
	unsigned short GFLGT_GetNumDevices ( void );
	GFDEVRESULT GFLGT_GetControlVals( int nDevIndex, short* pnWheelVal, unsigned char* pbSwitchVals );
	GFDEVRESULT GFLGT_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
	GFDEVRESULT GFLGT_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
	GFDEVRESULT GFLGT_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GFLGT_SetBrightness( int nDevIndex, int nBrightLevel );
    
	// GF-166 specific API functions
	unsigned short GF166_GetNumDevices ( void );
    GFDEVRESULT GF166_GetControlVals( int nDevIndex, short *pnLgDialVal, short *pnSmDialVal, unsigned char* pbSwitchVals );
	GFDEVRESULT GF166_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
	GFDEVRESULT GF166_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
    GFDEVRESULT GF166_SetLDisplayText( int nDevIndex, char* pszText );
	GFDEVRESULT GF166_SetLDisplaySegments( int nDevIndex, unsigned char* pszSegData );
	GFDEVRESULT GF166_SetRDisplayText( int nDevIndex, char* pszText );
	GFDEVRESULT GF166_SetRDisplaySegments( int nDevIndex, unsigned char* pszSegData );
	GFDEVRESULT GF166_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GF166_SetBrightness( int nDevIndex, int nBrightLevel );	
    
	// GF-MCP specific API functions
    unsigned short GFMCP_GetNumDevices ( void );
    GFDEVRESULT GFMCP_GetControlVals( int nDevIndex,
                                      short* pnADialVal, short* pnBDialVal, short* pnCDialVal, short* pnDDialVal, short* pnEDialVal,
                                      unsigned char* pbSwitchVals_1_8, unsigned char* pbSwitchVals_9_16 );
    GFDEVRESULT GFMCP_GetIndicators( int nDevIndex, unsigned char* pbIndicatorState );
    GFDEVRESULT GFMCP_SetIndicators( int nDevIndex, unsigned char bIndicatorState );
    GFDEVRESULT GFMCP_SetADisplayText( int nDevIndex, char* pszText );
    GFDEVRESULT GFMCP_SetADisplaySegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFMCP_SetBDisplayText( int nDevIndex, char* pszText );
    GFDEVRESULT GFMCP_SetBDisplaySegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFMCP_SetCDisplayText( int nDevIndex, char* pszText );
    GFDEVRESULT GFMCP_SetCDisplaySegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFMCP_SetDDisplayText( int nDevIndex, char* pszText );
    GFDEVRESULT GFMCP_SetDDisplaySegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFMCP_SetEDisplayText( int nDevIndex, char* pszText );
    GFDEVRESULT GFMCP_SetEDisplaySegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFMCP_GetBrightness( int nDevIndex, int* pnBrightLevel );
    GFDEVRESULT GFMCP_SetBrightness( int nDevIndex, int nBrightLevel );	

	// GF-ATC specific API functions
	unsigned short GFATC_GetNumDevices ( void );
    GFDEVRESULT GFATC_GetControlVals( int nDevIndex, short *pnDialVal, unsigned char* pbSwitchVals );
    GFDEVRESULT GFATC_SetDigit( int nDevIndex, char* szValue );
	GFDEVRESULT GFATC_SetDigitSegments( int nDevIndex, unsigned char* pszSegData );
    GFDEVRESULT GFATC_GetBrightness( int nDevIndex, int* pnBrightLevel );
	GFDEVRESULT GFATC_SetBrightness( int nDevIndex, int nBrightLevel );	

    // GF-TQ6 specific API functions
    unsigned short GFTQ6_GetNumDevices( void );
    GFDEVRESULT GFTQ6_GetControlVals( int nDevIndex,
                                      unsigned char* pnLeverAVal, unsigned char* pnLeverBVal, unsigned char* pnLeverCVal,
                                      unsigned char* pnLeverDVal, unsigned char* pnLeverEVal, unsigned char* pnLeverFVal,
                                      unsigned char* pbSwitchVals );
#if defined( __cplusplus)
} // extern "C"
#endif

// _stdcall versions of GFDEV API functions.  These are for use by apps built using non-C
//   languages (Visual Basic, Delphi, etc.)  _stdcall is equivalent to _far _pascal.
//
// GFDEV API management functions
GFDEVRESULT _stdcall GFDev_Init_stdcall( HINSTANCE hAppInstance );
GFDEVRESULT _stdcall GFDev_GetDeviceInfo_stdcall( GFDEV_HW_TYPE HWType, int nDevIndex, LPGFDEVICEINFO pGFDI );
GFDEVRESULT _stdcall GFDev_Terminate_stdcall( void );
BOOL _stdcall GFDev_RegisterInputCallback_stdcall( BOOL (_stdcall *pfnInputCallback)(GFDEV_HW_TYPE, unsigned short, unsigned long) );
BOOL _stdcall GFDev_UnregisterInputCallback_stdcall( void );
BOOL _stdcall GFDev_RegisterConnectCallback_stdcall( BOOL (_stdcall *pfnConnectCallback)(GFDEV_HW_TYPE, unsigned short, GFDEV_EVENT_TOKEN) );
BOOL _stdcall GFDev_UnregisterConnectCallback_stdcall( void );
BOOL _stdcall GFDev_RegisterWakeupCallback_stdcall( BOOL (_stdcall *pfnWakeupCallback)( void ), DWORD dwCallbackInterval );
BOOL _stdcall GFDev_UnregisterWakeupCallback_stdcall( void );

// GF-45 specific API functions
unsigned short _stdcall GF45_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GF45_GetDialVals_stdcall( int nDevIndex, short *pnLDialVal, short *pnRDialVal );
GFDEVRESULT _stdcall GF45_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );	
GFDEVRESULT _stdcall GF45_SetAlpha_stdcall( int nDevIndex, char* szValue );
GFDEVRESULT _stdcall GF45_SetAlphaSegments_stdcall( int nDevIndex, char* pszSegData );
GFDEVRESULT _stdcall GF45_SetNumeric_stdcall( int nDevIndex, char* szValue );
GFDEVRESULT _stdcall GF45_SetNumericSegments_stdcall( int nDevIndex, char* pszSegData );

// GF-46 specific API functions
unsigned short _stdcall GF46_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GF46_GetControlVals_stdcall( int nDevIndex, short *pnLgDialVal, short *pnSmDialVal, unsigned char* pbSwitchVal );
GFDEVRESULT _stdcall GF46_SetAlpha_stdcall( int nDevIndex, char* szValue );
GFDEVRESULT _stdcall GF46_SetAlphaSegments_stdcall( int nDevIndex, char* pszSegData );
GFDEVRESULT _stdcall GF46_SetNumeric_stdcall( int nDevIndex, char* szValue );
GFDEVRESULT _stdcall GF46_SetNumericSegments_stdcall( int nDevIndex, char* pszSegData );
GFDEVRESULT _stdcall GF46_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GF46_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );	

// GF-P8 specific API functions
unsigned short _stdcall GFP8_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFP8_GetSwitchVals_stdcall( int nDevIndex, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GFP8_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GFP8_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GFP8_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFP8_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );

// GF-RP48 specific API functions
unsigned short _stdcall GFRP48_GetNumDevices_stdcall ( void );
GFDEVRESULT _stdcall GFRP48_GetControlVals_stdcall( int nDevIndex, short* pnADialVal, short* pnBDialVal, short* pnCDialVal, short* pnDDialVal, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GFRP48_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GFRP48_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GFRP48_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFRP48_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );

// GF-T8 specific API functions
unsigned short _stdcall GFT8_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFT8_GetSwitchVals_stdcall( int nDevIndex, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GFT8_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GFT8_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GFT8_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFT8_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );

// GF-LGT specific API functions
unsigned short _stdcall GFLGT_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFLGT_GetControlVals_stdcall( int nDevIndex, short* pnWheelVal, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GFLGT_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GFLGT_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GFLGT_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFLGT_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );

// GF-166 specific API functions
unsigned short _stdcall GF166_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GF166_GetControlVals_stdcall( int nDevIndex, short *pnLgDialVal, short *pnSmDialVal, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GF166_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GF166_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GF166_SetLDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GF166_SetLDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GF166_SetRDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GF166_SetRDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GF166_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GF166_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );

// GF-MCP specific API functions
unsigned short _stdcall GFMCP_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFMCP_GetControlVals_stdcall( int nDevIndex, short *pnADialVal, short *pnBDialVal, short* pnCDialVal, short* pnDDialVal, short* pnEDialVal, unsigned char* pbSwitchVals_1_8, unsigned char* pbSwitchVals_9_16 );
GFDEVRESULT _stdcall GFMCP_GetIndicators_stdcall( int nDevIndex, unsigned char* pbIndicatorState );
GFDEVRESULT _stdcall GFMCP_SetIndicators_stdcall( int nDevIndex, unsigned char bIndicatorState );
GFDEVRESULT _stdcall GFMCP_SetADisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GFMCP_SetADisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFMCP_SetBDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GFMCP_SetBDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFMCP_SetCDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GFMCP_SetCDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFMCP_SetDDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GFMCP_SetDDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFMCP_SetEDisplayText_stdcall( int nDevIndex, char* pszText );
GFDEVRESULT _stdcall GFMCP_SetEDisplaySegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFMCP_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFMCP_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );	

// GF-ATC specific API functions
unsigned short _stdcall GFATC_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFATC_GetControlVals_stdcall( int nDevIndex, short *pnDialVal, unsigned char* pbSwitchVals );
GFDEVRESULT _stdcall GFATC_SetDigit_stdcall( int nDevIndex, char* szValue );
GFDEVRESULT _stdcall GFATC_SetDigitSegments_stdcall( int nDevIndex, unsigned char* pszSegData );
GFDEVRESULT _stdcall GFATC_GetBrightness_stdcall( int nDevIndex, int* pnBrightLevel );
GFDEVRESULT _stdcall GFATC_SetBrightness_stdcall( int nDevIndex, int nBrightLevel );	

// GF-TQ6 specific API functions
unsigned short _stdcall GFTQ6_GetNumDevices_stdcall( void );
GFDEVRESULT _stdcall GFTQ6_GetControlVals_stdcall( int nDevIndex, short *pnLeverAVal, short *pnLeverBVal, short* pnLeverCVal, short* pnLeverDVal, short* pnLeverEVal, short* pnLeverFVal, unsigned char* pbSwitchVals );

#pragma pack( pop, gfdevapi_h ) // Ensure previous pack value is restored

#endif // #ifdef GFDEVAPI_H_DEFINED_